@@ -1,6 +1,6 @@
 /*
-  The oSIP library implements the Session Initiation Protocol (SIP -rfc2543-)
-  Copyright (C) 2001  Aymeric MOIZARD jack@atosc.org
+  The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -36,7 +36,7 @@
 
 /**
  * Structure for Content-Encoding headers.
- * @defvar osip_content_encoding_t
+ * @var osip_content_encoding_t
  */
   typedef osip_content_length_t osip_content_encoding_t;
 
@@ -62,12 +62,12 @@ extern "C"
  * @param header The element to work on.
  * @param dest A pointer on the new allocated string.
  */
-#define osip_content_encoding_to_str(header, dest)  osip_content_length_to_str(header, dest)
+#define osip_content_encoding_to_str  osip_content_length_to_str
 /**
  * Free a Content-Encoding element.
  * @param header The element to work on.
  */
-#define osip_content_encoding_free(header)      osip_content_length_free(header)
+#define osip_content_encoding_free      osip_content_length_free
 /**
  * Clone a Content-Encoding element.
  * @param header The element to work on.
