@@ -1,6 +1,6 @@
 /*
-  The oSIP library implements the Session Initiation Protocol (SIP -rfc2543-)
-  Copyright (C) 2001  Aymeric MOIZARD jack@atosc.org
+  The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -31,21 +31,26 @@
 
 /**
  * @defgroup oSIP_BODY oSIP body API
- * @ingroup oSIP
+ * @ingroup osip2_parser
  * @{
  */
 
 /**
- * Structure for Body
- * @defvar osip_body_t
+ * Structure for holding Body
+ * @var osip_body_t
  */
 typedef struct osip_body osip_body_t;
 
+/**
+ * Structure for holding Body
+ * @struct osip_body
+ */
 struct osip_body
 {
-  char *body;
-  osip_list_t *headers;
-  osip_content_type_t *content_type;
+  char *body;                        /**< buffer containing data */
+  size_t length;                     /**< length of data */
+  osip_list_t *headers;              /**< List of headers (when mime is used) */
+  osip_content_type_t *content_type; /**< Content-Type (when mime is used) */
 };
 
 
@@ -68,8 +73,9 @@ extern "C"
  * Parse a osip_body_t element.
  * @param body The element to work on.
  * @param buf The buffer to parse.
+ * @param length The length of the buffer to parse.
  */
-  int osip_body_parse (osip_body_t * body, const char *buf);
+  int osip_body_parse (osip_body_t * body, const char *buf, size_t length);
 /**
  * Clone a osip_body_t element.
  * @param body The element to clone.
@@ -80,14 +86,16 @@ extern "C"
  * Parse a osip_body_t element. (for mime message format) (NOT TESTED, use with care)
  * @param body The element to work on.
  * @param buf The buffer to parse.
+ * @param length The length of the buffer to parse.
  */
-  int osip_body_parse_mime (osip_body_t * body, const char *buf);
+  int osip_body_parse_mime (osip_body_t * body, const char *buf, size_t length);
 /**
  * Get a string representation of a osip_body_t element.
  * @param body The element to work on.
  * @param dest The resulting buffer.
+ * @param length The length of the returned buffer.
  */
-  int osip_body_to_str (const osip_body_t * body, char **dest);
+  int osip_body_to_str (const osip_body_t * body, char **dest, size_t * length);
 
 /**
  * Set the Content-Type header in the osip_body_t element.
@@ -99,10 +107,11 @@ extern "C"
 /**
  * Add a header in the osip_body_t element.
  * @param body The element to work on.
+ * @param hname The header string name.
  * @param hvalue The header string value.
  */
   int osip_body_set_header (osip_body_t * body, const char *hname,
-			    const char *hvalue);
+                            const char *hvalue);
 
 #ifdef __cplusplus
 }
