@@ -64,7 +64,7 @@ __osip_global_init ()
   ixt_fastmutex = osip_mutex_init ();
 
 #endif
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 static void
@@ -143,7 +143,7 @@ osip_ixt_lock (osip_t * osip)
 #ifdef OSIP_MT
   return osip_mutex_lock (ixt_fastmutex);
 #else
-  return 0;
+  return OSIP_SUCCESS;
 #endif
 }
 
@@ -153,7 +153,7 @@ osip_ixt_unlock (osip_t * osip)
 #ifdef OSIP_MT
   return osip_mutex_unlock (ixt_fastmutex);
 #else
-  return 0;
+  return OSIP_SUCCESS;
 #endif
 }
 
@@ -196,7 +196,7 @@ ixt_init (ixt_t ** ixt)
 
   *ixt = pixt = (ixt_t *) osip_malloc (sizeof (ixt_t));
   if (pixt == NULL)
-    return -1;
+    return OSIP_NOMEM;
   pixt->dialog = NULL;
   pixt->msg2xx = NULL;
   pixt->ack = NULL;
@@ -207,7 +207,7 @@ ixt_init (ixt_t ** ixt)
   pixt->dest = NULL;
   pixt->port = 5060;
   pixt->sock = -1;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 void
@@ -347,7 +347,7 @@ osip_ict_lock (osip_t * osip)
 #ifdef OSIP_MT
   return osip_mutex_lock (ict_fastmutex);
 #else
-  return 0;
+  return OSIP_SUCCESS;
 #endif
 }
 
@@ -357,7 +357,7 @@ osip_ict_unlock (osip_t * osip)
 #ifdef OSIP_MT
   return osip_mutex_unlock (ict_fastmutex);
 #else
-  return 0;
+  return OSIP_SUCCESS;
 #endif
 }
 
@@ -367,7 +367,7 @@ osip_ist_lock (osip_t * osip)
 #ifdef OSIP_MT
   return osip_mutex_lock (ist_fastmutex);
 #else
-  return 0;
+  return OSIP_SUCCESS;
 #endif
 }
 
@@ -377,7 +377,7 @@ osip_ist_unlock (osip_t * osip)
 #ifdef OSIP_MT
   return osip_mutex_unlock (ist_fastmutex);
 #else
-  return 0;
+  return OSIP_SUCCESS;
 #endif
 }
 
@@ -387,7 +387,7 @@ osip_nict_lock (osip_t * osip)
 #ifdef OSIP_MT
   return osip_mutex_lock (nict_fastmutex);
 #else
-  return 0;
+  return OSIP_SUCCESS;
 #endif
 }
 
@@ -397,7 +397,7 @@ osip_nict_unlock (osip_t * osip)
 #ifdef OSIP_MT
   return osip_mutex_unlock (nict_fastmutex);
 #else
-  return 0;
+  return OSIP_SUCCESS;
 #endif
 }
 
@@ -407,7 +407,7 @@ osip_nist_lock (osip_t * osip)
 #ifdef OSIP_MT
   return osip_mutex_lock (nist_fastmutex);
 #else
-  return 0;
+  return OSIP_SUCCESS;
 #endif
 }
 
@@ -417,7 +417,7 @@ osip_nist_unlock (osip_t * osip)
 #ifdef OSIP_MT
   return osip_mutex_unlock (nist_fastmutex);
 #else
-  return 0;
+  return OSIP_SUCCESS;
 #endif
 }
 
@@ -479,7 +479,7 @@ __osip_add_ict (osip_t * osip, osip_transaction_t * ict)
 #ifdef OSIP_MT
   osip_mutex_unlock (ict_fastmutex);
 #endif
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -520,7 +520,7 @@ __osip_add_ist (osip_t * osip, osip_transaction_t * ist)
 #ifdef OSIP_MT
   osip_mutex_unlock (ist_fastmutex);
 #endif
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -562,7 +562,7 @@ __osip_add_nict (osip_t * osip, osip_transaction_t * nict)
 #ifdef OSIP_MT
   osip_mutex_unlock (nict_fastmutex);
 #endif
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -603,7 +603,7 @@ __osip_add_nist (osip_t * osip, osip_transaction_t * nist)
 #ifdef OSIP_MT
   osip_mutex_unlock (nist_fastmutex);
 #endif
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -612,7 +612,7 @@ osip_remove_transaction (osip_t * osip, osip_transaction_t * tr)
   int i = -1;
 
   if (tr == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (tr->ctx_type == ICT)
     i = __osip_remove_ict_transaction (osip, tr);
   else if (tr->ctx_type == IST)
@@ -622,7 +622,7 @@ osip_remove_transaction (osip_t * osip, osip_transaction_t * tr)
   else if (tr->ctx_type == NIST)
     i = __osip_remove_nist_transaction (osip, tr);
   else
-    return -1;
+    return OSIP_BADPARAMETER;
   return i;
 }
 
@@ -672,14 +672,14 @@ __osip_remove_ict_transaction (osip_t * osip, osip_transaction_t * ict)
 #ifdef OSIP_MT
           osip_mutex_unlock (ict_fastmutex);
 #endif
-          return 0;
+          return OSIP_SUCCESS;
         }
       tmp = (osip_transaction_t *) osip_list_get_next (&iterator);
     }
 #ifdef OSIP_MT
   osip_mutex_unlock (ict_fastmutex);
 #endif
-  return -1;
+  return OSIP_UNDEFINED_ERROR;
 }
 
 int
@@ -729,14 +729,14 @@ __osip_remove_ist_transaction (osip_t * osip, osip_transaction_t * ist)
 #ifdef OSIP_MT
           osip_mutex_unlock (ist_fastmutex);
 #endif
-          return 0;
+          return OSIP_SUCCESS;
         }
       tmp = (osip_transaction_t *) osip_list_get_next (&iterator);
     }
 #ifdef OSIP_MT
   osip_mutex_unlock (ist_fastmutex);
 #endif
-  return -1;
+  return OSIP_UNDEFINED_ERROR;
 }
 
 int
@@ -786,14 +786,14 @@ __osip_remove_nict_transaction (osip_t * osip, osip_transaction_t * nict)
 #ifdef OSIP_MT
           osip_mutex_unlock (nict_fastmutex);
 #endif
-          return 0;
+          return OSIP_SUCCESS;
         }
       tmp = (osip_transaction_t *) osip_list_get_next (&iterator);
     }
 #ifdef OSIP_MT
   osip_mutex_unlock (nict_fastmutex);
 #endif
-  return -1;
+  return OSIP_UNDEFINED_ERROR;
 }
 
 int
@@ -843,14 +843,14 @@ __osip_remove_nist_transaction (osip_t * osip, osip_transaction_t * nist)
 #ifdef OSIP_MT
           osip_mutex_unlock (nist_fastmutex);
 #endif
-          return 0;
+          return OSIP_SUCCESS;
         }
       tmp = (osip_transaction_t *) osip_list_get_next (&iterator);
     }
 #ifdef OSIP_MT
   osip_mutex_unlock (nist_fastmutex);
 #endif
-  return -1;
+  return OSIP_UNDEFINED_ERROR;
 }
 
 #if 0
@@ -998,8 +998,8 @@ osip_find_transaction_and_add_event (osip_t * osip, osip_event_t * evt)
   osip_transaction_t *transaction = __osip_find_transaction (osip, evt, 1);
 
   if (transaction == NULL)
-    return -1;
-  return 0;
+    return OSIP_UNDEFINED_ERROR;
+  return OSIP_SUCCESS;
 }
 
 #ifndef OSIP_MT
@@ -1173,7 +1173,7 @@ osip_create_transaction (osip_t * osip, osip_event_t * evt)
     }
 
   i = osip_transaction_init (&transaction, ctx_type, osip, evt->sip);
-  if (i == -1)
+  if (i != 0)
     {
       return NULL;
     }
@@ -1202,7 +1202,7 @@ osip_transaction_find (osip_list_t * transactions, osip_event_t * evt)
       osip_generic_param_t *b_request;
       osip_via_t *topvia_request;
 
-      topvia_request = osip_list_get (evt->sip->vias, 0);
+      topvia_request = osip_list_get (&evt->sip->vias, 0);
       if (topvia_request == NULL)
         {
           OSIP_TRACE (osip_trace
@@ -1254,7 +1254,7 @@ osip_transaction_find (osip_list_t * transactions, osip_event_t * evt)
       osip_generic_param_t *b_request;
       osip_via_t *topvia_request;
 
-      topvia_request = osip_list_get (evt->sip->vias, 0);
+      topvia_request = osip_list_get (&evt->sip->vias, 0);
       if (topvia_request == NULL)
         {
           OSIP_TRACE (osip_trace
@@ -1335,7 +1335,7 @@ increase_ref_count (void)
   osip_mutex_unlock (ref_mutex);
 #endif
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 static void
@@ -1363,12 +1363,14 @@ decrease_ref_count (void)
 int
 osip_init (osip_t ** osip)
 {
-  if (increase_ref_count () != 0)
-    return -1;
+  int i;
+  i = increase_ref_count ();
+  if (i != 0)
+    return i;
 
   *osip = (osip_t *) osip_malloc (sizeof (osip_t));
   if (*osip == NULL)
-    return -1;                  /* allocation failed */
+    return OSIP_NOMEM;                  /* allocation failed */
 
   memset (*osip, 0, sizeof (osip_t));
 
@@ -1376,7 +1378,6 @@ osip_init (osip_t ** osip)
   osip_list_init (&(*osip)->osip_ist_transactions);
   osip_list_init (&(*osip)->osip_nict_transactions);
   osip_list_init (&(*osip)->osip_nist_transactions);
-
   osip_list_init (&(*osip)->ixt_retransmissions);
 
 #if defined(HAVE_DICT_DICT_H)
@@ -1399,7 +1400,7 @@ osip_init (osip_t ** osip)
   (*osip)->osip_nist_hastable = rb_tree_new ((dict_cmp_func) strcmp, NULL, NULL);
 #endif
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 void
@@ -1445,7 +1446,7 @@ osip_ict_execute (osip_t * osip)
 #ifdef OSIP_MT
       osip_mutex_unlock (ict_fastmutex);
 #endif
-      return 0;
+      return OSIP_SUCCESS;
     }
   array = osip_malloc (sizeof (void *) * len);
   if (array==NULL)
@@ -1453,7 +1454,7 @@ osip_ict_execute (osip_t * osip)
 #ifdef OSIP_MT
       osip_mutex_unlock (ict_fastmutex);
 #endif
-      return 0;
+      return OSIP_NOMEM; /* OSIP_SUCCESS; */
     }
   transaction =
     (osip_transaction_t *) osip_list_get_first (&osip->osip_ict_transactions,
@@ -1484,7 +1485,7 @@ osip_ict_execute (osip_t * osip)
 
   osip_free (array);
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -1508,7 +1509,7 @@ osip_ist_execute (osip_t * osip)
 #ifdef OSIP_MT
       osip_mutex_unlock (ist_fastmutex);
 #endif
-      return 0;
+      return OSIP_SUCCESS;
     }
   array = osip_malloc (sizeof (void *) * len);
   if (array==NULL)
@@ -1516,7 +1517,7 @@ osip_ist_execute (osip_t * osip)
 #ifdef OSIP_MT
       osip_mutex_unlock (ist_fastmutex);
 #endif
-      return 0;
+      return OSIP_NOMEM; /* OSIP_SUCCESS; */
     }
   transaction =
     (osip_transaction_t *) osip_list_get_first (&osip->osip_ist_transactions,
@@ -1548,7 +1549,7 @@ osip_ist_execute (osip_t * osip)
 
   osip_free (array);
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -1572,7 +1573,7 @@ osip_nict_execute (osip_t * osip)
 #ifdef OSIP_MT
       osip_mutex_unlock (nict_fastmutex);
 #endif
-      return 0;
+      return OSIP_SUCCESS;
     }
   array = osip_malloc (sizeof (void *) * len);
   if (array==NULL)
@@ -1580,7 +1581,7 @@ osip_nict_execute (osip_t * osip)
 #ifdef OSIP_MT
       osip_mutex_unlock (nict_fastmutex);
 #endif
-      return 0;
+      return OSIP_NOMEM; /* OSIP_SUCCESS; */
     }
   transaction =
     (osip_transaction_t *) osip_list_get_first (&osip->osip_nict_transactions,
@@ -1611,7 +1612,7 @@ osip_nict_execute (osip_t * osip)
 
   osip_free (array);
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -1635,7 +1636,7 @@ osip_nist_execute (osip_t * osip)
 #ifdef OSIP_MT
       osip_mutex_unlock (nist_fastmutex);
 #endif
-      return 0;
+      return OSIP_SUCCESS;
     }
   array = osip_malloc (sizeof (void *) * len);
   if (array==NULL)
@@ -1643,7 +1644,7 @@ osip_nist_execute (osip_t * osip)
 #ifdef OSIP_MT
       osip_mutex_unlock (nist_fastmutex);
 #endif
-      return 0;
+      return OSIP_NOMEM; /* OSIP_SUCCESS; */
     }
   transaction =
     (osip_transaction_t *) osip_list_get_first (&osip->osip_nist_transactions,
@@ -1674,7 +1675,7 @@ osip_nist_execute (osip_t * osip)
 
   osip_free (array);
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 void
@@ -2101,11 +2102,11 @@ osip_set_message_callback (osip_t * config, int type, osip_message_cb_t cb)
       OSIP_TRACE (osip_trace
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "invalid callback type %d\n", type));
-      return -1;
+      return OSIP_BADPARAMETER;
     }
   config->msg_callbacks[type] = cb;
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -2117,10 +2118,10 @@ osip_set_kill_transaction_callback (osip_t * config, int type,
       OSIP_TRACE (osip_trace
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "invalid callback type %d\n", type));
-      return -1;
+      return OSIP_BADPARAMETER;
     }
   config->kill_callbacks[type] = cb;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -2132,8 +2133,8 @@ osip_set_transport_error_callback (osip_t * config, int type,
       OSIP_TRACE (osip_trace
                   (__FILE__, __LINE__, OSIP_ERROR, NULL,
                    "invalid callback type %d\n", type));
-      return -1;
+      return OSIP_BADPARAMETER;
     }
   config->tp_error_callbacks[type] = cb;
-  return 0;
+  return OSIP_SUCCESS;
 }
