@@ -67,7 +67,7 @@ osip_mutex_lock (struct osip_mutex *_mut)
   osip_mutex_t *mut = (osip_mutex_t *) _mut;
 
   if (mut == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   return pthread_mutex_lock (mut);
 }
 
@@ -77,7 +77,7 @@ osip_mutex_unlock (struct osip_mutex *_mut)
   osip_mutex_t *mut = (osip_mutex_t *) _mut;
 
   if (mut == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   return pthread_mutex_unlock (mut);
 }
 
@@ -108,10 +108,10 @@ osip_sem_destroy (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return 0;
+    return OSIP_SUCCESS;
   osip_mutex_destroy(sem->_sem_mutex);
   osip_free (sem);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -120,11 +120,11 @@ osip_sem_post (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   osip_mutex_lock(sem->_sem_mutex);
   sem->_sem_counter++;
   osip_mutex_unlock(sem->_sem_mutex);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -133,7 +133,7 @@ osip_sem_wait (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
 
   /* poor emulation... */
   while (1)
@@ -143,12 +143,12 @@ osip_sem_wait (struct osip_sem *_sem)
 	{
 	  sem->_sem_counter--;
 	  osip_mutex_unlock(sem->_sem_mutex);
-	  return 0;
+	  return OSIP_SUCCESS;
 	}
       osip_mutex_unlock(sem->_sem_mutex);
       osip_usleep(1000);
     }
-  return -1;
+  return OSIP_UNDEFINED_ERROR;
 }
 
 int
@@ -157,16 +157,16 @@ osip_sem_trywait (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   osip_mutex_lock(sem->_sem_mutex);
   if (sem->_sem_counter>0)
     {
       sem->_sem_counter--;
       osip_mutex_unlock(sem->_sem_mutex);
-      return 0;
+      return OSIP_SUCCESS;
     }
   osip_mutex_unlock(sem->_sem_mutex);
-  return -1;
+  return OSIP_UNDEFINED_ERROR;
 }
 
 #elif (defined(HAVE_SEMAPHORE_H) && !defined(__APPLE_CC__)) || defined(HAVE_PTHREAD_WIN32)
@@ -192,10 +192,10 @@ osip_sem_destroy (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return 0;
+    return OSIP_SUCCESS;
   sem_destroy (sem);
   osip_free (sem);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -204,7 +204,7 @@ osip_sem_post (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   return sem_post (sem);
 }
 
@@ -214,7 +214,7 @@ osip_sem_wait (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   return sem_wait (sem);
 }
 
@@ -224,7 +224,7 @@ osip_sem_trywait (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   return sem_trywait (sem);
 }
 
@@ -268,11 +268,11 @@ osip_sem_destroy (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return 0;
+    return OSIP_SUCCESS;
   val.val = 0;
   semctl (sem->semid, 0, IPC_RMID, val);
   osip_free (sem);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -282,7 +282,7 @@ osip_sem_post (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   sb.sem_num = 0;
   sb.sem_op = 1;
   sb.sem_flg = 0;
@@ -296,7 +296,7 @@ osip_sem_wait (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   sb.sem_num = 0;
   sb.sem_op = -1;
   sb.sem_flg = 0;
@@ -310,7 +310,7 @@ osip_sem_trywait (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   sb.sem_num = 0;
   sb.sem_op = -1;
   sb.sem_flg = IPC_NOWAIT;
@@ -345,7 +345,7 @@ osip_mutex_lock (struct osip_mutex *_mut)
   osip_mutex_t *mut = (osip_mutex_t *) _mut;
 
   if (mut == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   return semTake (mut, WAIT_FOREVER);
 }
 
@@ -355,7 +355,7 @@ osip_mutex_unlock (struct osip_mutex *_mut)
   osip_mutex_t *mut = (osip_mutex_t *) _mut;
 
   if (mut == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   return semGive (mut);
 }
 
@@ -381,10 +381,10 @@ osip_sem_destroy (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return 0;
+    return OSIP_SUCCESS;
   semDelete (sem->semId);
   osip_free (sem);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -393,7 +393,7 @@ osip_sem_post (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   return semGive (sem->semId);
 }
 
@@ -403,7 +403,7 @@ osip_sem_wait (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   return semTake (sem->semId, WAIT_FOREVER);
 }
 
@@ -413,7 +413,7 @@ osip_sem_trywait (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   return semTake (sem->semId, NO_WAIT);
 }
 
@@ -423,7 +423,7 @@ osip_sem_trywait (struct osip_sem *_sem)
 #if (defined(WIN32) || defined(_WIN32_WCE)) && !defined(HAVE_PTHREAD_WIN32)
 #include <limits.h>
 
-#if (_WIN32_WINNT >= 0x0500)
+#if (_WIN32_WINNT >= 0x0403) && !defined(_WIN32_WCE)
 struct osip_mutex *
 osip_mutex_init ()
 {
@@ -455,7 +455,7 @@ osip_mutex_lock (struct osip_mutex *_mut)
   osip_mutex_t *mut = (osip_mutex_t *) _mut;
 
   if (mut == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   EnterCriticalSection (&mut->h);
 
   return (0);
@@ -467,7 +467,7 @@ osip_mutex_unlock (struct osip_mutex *_mut)
   osip_mutex_t *mut = (osip_mutex_t *) _mut;
 
   if (mut == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   LeaveCriticalSection (&mut->h);
   return (0);
 }
@@ -504,7 +504,7 @@ osip_mutex_lock (struct osip_mutex *_mut)
   osip_mutex_t *mut = (osip_mutex_t *) _mut;
 
   if (mut == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if ((err = WaitForSingleObject (mut->h, INFINITE)) == WAIT_OBJECT_0)
     return (0);
   return (EBUSY);
@@ -516,7 +516,7 @@ osip_mutex_unlock (struct osip_mutex *_mut)
   osip_mutex_t *mut = (osip_mutex_t *) _mut;
 
   if (mut == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   ReleaseMutex (mut->h);
   return (0);
 }
@@ -542,7 +542,7 @@ osip_sem_destroy (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return 0;
+    return OSIP_SUCCESS;
   CloseHandle (sem->h);
   osip_free (sem);
   return (0);
@@ -554,7 +554,7 @@ osip_sem_post (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   ReleaseSemaphore (sem->h, 1, NULL);
   return (0);
 }
@@ -566,7 +566,7 @@ osip_sem_wait (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if ((err = WaitForSingleObject (sem->h, INFINITE)) == WAIT_OBJECT_0)
     return (0);
   if (err == WAIT_TIMEOUT)
@@ -581,7 +581,7 @@ osip_sem_trywait (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if ((err = WaitForSingleObject (sem->h, 0)) == WAIT_OBJECT_0)
     return (0);
   return (EBUSY);
@@ -620,7 +620,7 @@ osip_mutex_lock (struct osip_mutex *_mut)
   if (mut)
     {
       if (sm_p (mut->id, SM_WAIT, 0) != 0)
-        return (-1);
+        return OSIP_UNDEFINED_ERROR;
     }
   return (0);
 }
@@ -655,7 +655,7 @@ osip_sem_destroy (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return 0;
+    return OSIP_SUCCESS;
   sm_delete (sem->id);
   osip_free (sem);
   return (0);
@@ -667,7 +667,7 @@ osip_sem_post (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   return (sm_v (sem->id));
 }
 
@@ -677,7 +677,7 @@ osip_sem_wait (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (sm_p (sem->id, SM_WAIT, 0) != 0)
     return (-1);
   return (0);
@@ -689,9 +689,9 @@ osip_sem_trywait (struct osip_sem *_sem)
   osip_sem_t *sem = (osip_sem_t *) _sem;
 
   if (sem == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (sm_p (sem->id, SM_NOWAIT, 0) != 0)
-    return (-1);
+    return OSIP_UNDEFINED_ERROR;
   return (0);
 }
 
@@ -742,10 +742,10 @@ int osip_mutex_lock(struct osip_mutex *_mut)
 				       RTEMS_NO_TIMEOUT);
       if ( status != RTEMS_SUCCESSFUL )
 	{
-	  return -1;
+	  return OSIP_UNDEFINED_ERROR;
 	}
     }
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int osip_mutex_unlock(struct osip_mutex *_mut)
@@ -786,7 +786,7 @@ int osip_sem_destroy(struct osip_sem *_sem)
 
   if (sem == NULL)
     {
-      return 0;
+      return OSIP_SUCCESS;
     }
   rtems_semaphore_delete(sem->id);
   osip_free (sem);
@@ -799,7 +799,7 @@ int osip_sem_post(struct osip_sem *_sem)
 
   if (sem == NULL)
     {
-      return -1;
+      return OSIP_UNDEFINED_ERROR;
     }
   return rtems_semaphore_release( sem->id);
 }
@@ -810,11 +810,11 @@ int osip_sem_wait(struct osip_sem *_sem)
 
   if (sem == NULL)
     {
-      return -1;
+      return OSIP_BADPARAMETER;
     }
   if ( rtems_semaphore_obtain( sem->id, RTEMS_WAIT, RTEMS_NO_TIMEOUT) != RTEMS_SUCCESSFUL )
     {
-      return (-1);
+      return OSIP_UNDEFINED_ERROR;
     }
   return (0);
 }
@@ -825,11 +825,11 @@ int osip_sem_trywait(struct osip_sem *_sem)
 
   if (sem == NULL)
     {
-      return -1;
+      return OSIP_BADPARAMETER;
     }
   if ( rtems_semaphore_obtain( sem->id,RTEMS_NO_WAIT, 0) != RTEMS_SUCCESSFUL)
     {
-      return (-1);
+      return OSIP_UNDEFINED_ERROR;
     }
   return (0);
 }
