@@ -34,20 +34,20 @@ osip_message_set_allow (osip_message_t * sip, const char *hvalue)
   int i;
 
   if (hvalue == NULL || hvalue[0] == '\0')
-    return 0;
+    return OSIP_SUCCESS;
 
   i = osip_allow_init (&allow);
   if (i != 0)
-    return -1;
+    return i;
   i = osip_allow_parse (allow, hvalue);
   if (i != 0)
     {
       osip_allow_free (allow);
-      return -1;
+      return i;
     }
   sip->message_property = 2;
   osip_list_add (&sip->allows, allow, -1);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -57,7 +57,7 @@ osip_message_get_allow (const osip_message_t * sip, int pos, osip_allow_t ** des
 
   *dest = NULL;
   if (osip_list_size (&sip->allows) <= pos)
-    return -1;                  /* does not exist */
+    return OSIP_UNDEFINED_ERROR;     /* does not exist */
   allow = (osip_allow_t *) osip_list_get (&sip->allows, pos);
   *dest = allow;
   return pos;
