@@ -34,22 +34,22 @@ osip_message_set_call_id (osip_message_t * sip, const char *hvalue)
   int i;
 
   if (hvalue == NULL || hvalue[0] == '\0')
-    return 0;
+    return OSIP_SUCCESS;
 
   if (sip->call_id != NULL)
-    return -1;
+    return OSIP_SYNTAXERROR;
   i = osip_call_id_init (&(sip->call_id));
   if (i != 0)
-    return -1;
+    return i;
   sip->message_property = 2;
   i = osip_call_id_parse (sip->call_id, hvalue);
   if (i != 0)
     {
       osip_call_id_free (sip->call_id);
       sip->call_id = NULL;
-      return -1;
+      return i;
     }
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 #ifndef MINISIZE
@@ -67,10 +67,10 @@ osip_call_id_init (osip_call_id_t ** callid)
 {
   *callid = (osip_call_id_t *) osip_malloc (sizeof (osip_call_id_t));
   if (*callid == NULL)
-    return -1;
+    return OSIP_NOMEM;
   (*callid)->number = NULL;
   (*callid)->host = NULL;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 
@@ -111,20 +111,20 @@ osip_call_id_parse (osip_call_id_t * callid, const char *hvalue)
   else
     {
       if (end - host + 1 < 2)
-        return -1;
+        return OSIP_SYNTAXERROR;
       callid->host = (char *) osip_malloc (end - host);
       if (callid->host == NULL)
-        return -1;
+        return OSIP_NOMEM;
       osip_clrncpy (callid->host, host + 1, end - host - 1);
     }
   if (host - hvalue + 1 < 2)
-    return -1;
+    return OSIP_SYNTAXERROR;
   callid->number = (char *) osip_malloc (host - hvalue + 1);
   if (callid->number == NULL)
-    return -1;
+    return OSIP_NOMEM;
   osip_clrncpy (callid->number, hvalue, host - hvalue);
 
-  return 0;                     /* ok */
+  return OSIP_SUCCESS;                     /* ok */
 }
 
 /* returns the call_id as a string.          */
@@ -135,23 +135,23 @@ osip_call_id_to_str (const osip_call_id_t * callid, char **dest)
 {
   *dest = NULL;
   if ((callid == NULL) || (callid->number == NULL))
-    return -1;
+    return OSIP_BADPARAMETER;
 
   if (callid->host == NULL)
     {
       *dest = (char *) osip_malloc (strlen (callid->number) + 1);
       if (*dest == NULL)
-        return -1;
+        return OSIP_NOMEM;
       sprintf (*dest, "%s", callid->number);
   } else
     {
       *dest =
         (char *) osip_malloc (strlen (callid->number) + strlen (callid->host) + 2);
       if (*dest == NULL)
-        return -1;
+        return OSIP_NOMEM;
       sprintf (*dest, "%s@%s", callid->number, callid->host);
     }
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 char *
@@ -190,19 +190,19 @@ osip_call_id_clone (const osip_call_id_t * callid, osip_call_id_t ** dest)
 
   *dest = NULL;
   if (callid == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (callid->number == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
 
   i = osip_call_id_init (&ci);
-  if (i == -1)                  /* allocation failed */
-    return -1;
+  if (i != 0)                  /* allocation failed */
+    return i;
   ci->number = osip_strdup (callid->number);
   if (callid->host != NULL)
     ci->host = osip_strdup (callid->host);
 
   *dest = ci;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -210,21 +210,21 @@ osip_call_id_match (osip_call_id_t * callid1, osip_call_id_t * callid2)
 {
 
   if (callid1 == NULL || callid2 == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (callid1->number == NULL || callid2->number == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
 
   if (0 != strcmp (callid1->number, callid2->number))
-    return -1;
+    return OSIP_UNDEFINED_ERROR;
 
   if ((callid1->host == NULL) && (callid2->host == NULL))
-    return 0;
+    return OSIP_SUCCESS;
   if ((callid1->host == NULL) && (callid2->host != NULL))
-    return -1;
+    return OSIP_UNDEFINED_ERROR;
   if ((callid1->host != NULL) && (callid2->host == NULL))
-    return -1;
+    return OSIP_UNDEFINED_ERROR;
   if (0 != strcmp (callid1->host, callid2->host))
-    return -1;
+    return OSIP_UNDEFINED_ERROR;
 
-  return 0;
+  return OSIP_SUCCESS;
 }
