@@ -34,20 +34,20 @@ osip_message_set_call_info (osip_message_t * sip, const char *hvalue)
   int i;
 
   if (hvalue == NULL || hvalue[0] == '\0')
-    return 0;
+    return OSIP_SUCCESS;
 
   i = osip_call_info_init (&call_info);
   if (i != 0)
-    return -1;
+    return i;
   i = osip_call_info_parse (call_info, hvalue);
   if (i != 0)                   /* allocation failed */
     {
       osip_call_info_free (call_info);
-      return -1;
+      return i;
     }
   sip->message_property = 2;
   osip_list_add (&sip->call_infos, call_info, -1);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -58,7 +58,7 @@ osip_message_get_call_info (const osip_message_t * sip, int pos,
 
   *dest = NULL;
   if (osip_list_size (&sip->call_infos) <= pos)
-    return -1;                  /* does not exist */
+    return OSIP_UNDEFINED_ERROR;     /* does not exist */
   call_info = (osip_call_info_t *) osip_list_get (&sip->call_infos, pos);
   *dest = call_info;
   return pos;
@@ -69,46 +69,47 @@ osip_call_info_init (osip_call_info_t ** call_info)
 {
   *call_info = (osip_call_info_t *) osip_malloc (sizeof (osip_call_info_t));
   if (*call_info == NULL)
-    return -1;
+    return OSIP_NOMEM;
 
   (*call_info)->element = NULL;
 
   osip_list_init (&(*call_info)->gen_params);
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
 osip_call_info_parse (osip_call_info_t * call_info, const char *hvalue)
 {
   const char *osip_call_info_params;
+  int i;
 
   osip_call_info_params = strchr (hvalue, '<');
   if (osip_call_info_params == NULL)
-    return -1;
+    return OSIP_SYNTAXERROR;
 
   osip_call_info_params = strchr (osip_call_info_params + 1, '>');
   if (osip_call_info_params == NULL)
-    return -1;
+    return OSIP_SYNTAXERROR;
 
   osip_call_info_params = strchr (osip_call_info_params + 1, ';');
 
   if (osip_call_info_params != NULL)
     {
-      if (__osip_generic_param_parseall
-          (&call_info->gen_params, osip_call_info_params) == -1)
-        return -1;
+	  i = __osip_generic_param_parseall(&call_info->gen_params, osip_call_info_params);
+      if (i != 0)
+        return i;
   } else
     osip_call_info_params = hvalue + strlen (hvalue);
 
   if (osip_call_info_params - hvalue + 1 < 2)
-    return -1;
+    return OSIP_SYNTAXERROR;
   call_info->element = (char *) osip_malloc (osip_call_info_params - hvalue + 1);
   if (call_info->element == NULL)
-    return -1;
+    return OSIP_NOMEM;
   osip_clrncpy (call_info->element, hvalue, osip_call_info_params - hvalue);
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 /* returns the call_info header as a string.  */
@@ -124,12 +125,12 @@ osip_call_info_to_str (const osip_call_info_t * call_info, char **dest)
 
   *dest = NULL;
   if ((call_info == NULL) || (call_info->element == NULL))
-    return -1;
+    return OSIP_BADPARAMETER;
 
   len = strlen (call_info->element) + 2;
   buf = (char *) osip_malloc (len);
   if (buf == NULL)
-    return -1;
+    return OSIP_NOMEM;
   *dest = buf;
 
   sprintf (buf, "%s", call_info->element);
@@ -158,7 +159,7 @@ osip_call_info_to_str (const osip_call_info_t * call_info, char **dest)
       }
   }
   *dest = buf;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 
@@ -186,23 +187,28 @@ osip_call_info_clone (const osip_call_info_t * ctt, osip_call_info_t ** dest)
 
   *dest = NULL;
   if (ctt == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (ctt->element == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
 
   i = osip_call_info_init (&ct);
   if (i != 0)                   /* allocation failed */
-    return -1;
+    return i;
   ct->element = osip_strdup (ctt->element);
+  if (ct->element==NULL)
+  {
+      osip_call_info_free (ct);
+	  return OSIP_NOMEM;
+  }
 
-  i = osip_list_clone(&ctt->gen_params, &ct->gen_params, (int *(*)(void *, void *)) &osip_generic_param_clone);
+  i = osip_list_clone(&ctt->gen_params, &ct->gen_params, &osip_generic_param_clone);
   if (i != 0)
     {
       osip_call_info_free (ct);
-      return -1;
+      return i;
     }
   *dest = ct;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 
