@@ -37,20 +37,20 @@ osip_message_set_content_encoding (osip_message_t * sip, const char *hvalue)
   int i;
 
   if (hvalue == NULL || hvalue[0] == '\0')
-    return 0;
+    return OSIP_SUCCESS;
 
   i = osip_content_encoding_init (&content_encoding);
   if (i != 0)
-    return -1;
+    return i;
   i = osip_content_encoding_parse (content_encoding, hvalue);
   if (i != 0)
     {
       osip_content_encoding_free (content_encoding);
-      return -1;
+      return i;
     }
   sip->message_property = 2;
   osip_list_add (&sip->content_encodings, content_encoding, -1);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -61,7 +61,7 @@ osip_message_get_content_encoding (const osip_message_t * sip, int pos,
 
   *dest = NULL;
   if (osip_list_size (&sip->content_encodings) <= pos)
-    return -1;                  /* does not exist */
+    return OSIP_UNDEFINED_ERROR;     /* does not exist */
   ce = (osip_content_encoding_t *) osip_list_get (&sip->content_encodings, pos);
   *dest = ce;
   return pos;
