@@ -32,14 +32,14 @@ osip_content_type_init (osip_content_type_t ** content_type)
   *content_type =
     (osip_content_type_t *) osip_malloc (sizeof (osip_content_type_t));
   if (*content_type == NULL)
-    return -1;
+    return OSIP_NOMEM;
 
   (*content_type)->type = NULL;
   (*content_type)->subtype = NULL;
 
   osip_list_init (&(*content_type)->gen_params);
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 /* adds the content_type header to message.              */
@@ -52,22 +52,23 @@ osip_message_set_content_type (osip_message_t * sip, const char *hvalue)
   int i;
 
   if (sip->content_type != NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
 
   if (hvalue == NULL || hvalue[0] == '\0')
-    return 0;
+    return OSIP_SUCCESS;
 
   i = osip_content_type_init (&(sip->content_type));
   if (i != 0)
-    return -1;
+    return i;
   sip->message_property = 2;
   i = osip_content_type_parse (sip->content_type, hvalue);
   if (i != 0)
     {
       osip_content_type_free (sip->content_type);
       sip->content_type = NULL;
+	  return i;
     }
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 #ifndef MINISIZE
@@ -90,6 +91,7 @@ osip_content_type_parse (osip_content_type_t * content_type, const char *hvalue)
 {
   char *subtype;
   char *osip_content_type_params;
+  int i;
 
   /* How to parse:
 
@@ -103,39 +105,39 @@ osip_content_type_parse (osip_content_type_t * content_type, const char *hvalue)
      ^          ^
    */
   if (hvalue == NULL || hvalue[0] == '\0')
-    return 0;                   /* It's valid to add empty Accept header! */
+    return OSIP_SUCCESS;                   /* It's valid to add empty Accept header! */
 
   subtype = strchr (hvalue, '/');
   osip_content_type_params = strchr (hvalue, ';');
 
   if (subtype == NULL)
-    return -1;                  /* do we really mind such an error */
+    return OSIP_SYNTAXERROR;                  /* do we really mind such an error */
 
   if (osip_content_type_params != NULL)
     {
-      if (__osip_generic_param_parseall (&content_type->gen_params,
-                                         osip_content_type_params) == -1)
-        return -1;
+		i = __osip_generic_param_parseall (&content_type->gen_params, osip_content_type_params);
+		if (i != 0)
+	        return i;
   } else
     osip_content_type_params = subtype + strlen (subtype);
 
   if (subtype - hvalue + 1 < 2)
-    return -1;
+    return OSIP_SYNTAXERROR;
   content_type->type = (char *) osip_malloc (subtype - hvalue + 1);
   if (content_type->type == NULL)
-    return -1;
+    return OSIP_NOMEM;
   osip_clrncpy (content_type->type, hvalue, subtype - hvalue);
 
   if (osip_content_type_params - subtype < 2)
-    return -1;
+    return OSIP_SYNTAXERROR;
   content_type->subtype =
     (char *) osip_malloc (osip_content_type_params - subtype);
   if (content_type->subtype == NULL)
-    return -1;
+    return OSIP_NOMEM;
   osip_clrncpy (content_type->subtype, subtype + 1,
                 osip_content_type_params - subtype - 1);
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 
@@ -152,13 +154,15 @@ osip_content_type_to_str (const osip_content_type_t * content_type, char **dest)
   *dest = NULL;
   if ((content_type == NULL) || (content_type->type == NULL)
       || (content_type->subtype == NULL))
-    return -1;
+    return OSIP_BADPARAMETER;
 
   /* try to guess a long enough length */
   len = strlen (content_type->type) + strlen (content_type->subtype) + 4        /* for '/', ' ', ';' and '\0' */
     + 10 * osip_list_size (&content_type->gen_params);
 
   buf = (char *) osip_malloc (len);
+  if (buf==NULL)
+	  return OSIP_NOMEM;
   tmp = buf;
 
   sprintf (tmp, "%s/%s", content_type->type, content_type->subtype);
@@ -184,7 +188,7 @@ osip_content_type_to_str (const osip_content_type_t * content_type, char **dest)
         if (u_param->gvalue == NULL)
           {
             osip_free (buf);
-            return -1;
+            return OSIP_SYNTAXERROR;
           }
         tmp_len = strlen (buf) + 4 + strlen (u_param->gname)
           + strlen (u_param->gvalue) + 1;
@@ -200,7 +204,7 @@ osip_content_type_to_str (const osip_content_type_t * content_type, char **dest)
       }
   }
   *dest = buf;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 
@@ -231,11 +235,11 @@ osip_content_type_clone (const osip_content_type_t * ctt,
 
   *dest = NULL;
   if (ctt == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
 
   i = osip_content_type_init (&ct);
   if (i != 0)                   /* allocation failed */
-    return -1;
+    return i;
   if (ctt->type != NULL)
     ct->type = osip_strdup (ctt->type);
   if (ctt->subtype != NULL)
@@ -254,12 +258,12 @@ osip_content_type_clone (const osip_content_type_t * ctt,
           {
             osip_content_type_free (ct);
             osip_free (ct);
-            return -1;
+            return i;
           }
         osip_list_add (&ct->gen_params, dest_param, -1);
         pos++;
       }
   }
   *dest = ct;
-  return 0;
+  return OSIP_SUCCESS;
 }
