@@ -38,19 +38,19 @@ osip_message_set_header (osip_message_t * sip, const char *hname,
   osip_header_t *h;
   int i;
 
-  if (hname == NULL)
-    return -1;
+  if (sip == NULL || hname == NULL)
+    return OSIP_BADPARAMETER;
 
   i = osip_header_init (&h);
   if (i != 0)
-    return -1;
+    return i;
 
   h->hname = (char *) osip_malloc (strlen (hname) + 1);
 
   if (h->hname == NULL)
     {
       osip_header_free (h);
-      return -1;
+      return OSIP_NOMEM;
     }
   osip_clrncpy (h->hname, hname, strlen (hname));
 
@@ -60,14 +60,14 @@ osip_message_set_header (osip_message_t * sip, const char *hname,
       if (h->hvalue == NULL)
         {
           osip_header_free (h);
-          return -1;
+          return OSIP_NOMEM;
         }
       osip_clrncpy (h->hvalue, hvalue, strlen (hvalue));
   } else
     h->hvalue = NULL;
   sip->message_property = 2;
   osip_list_add (&sip->headers, h, -1);
-  return 0;                     /* ok */
+  return OSIP_SUCCESS;                     /* ok */
 }
 
 /* Add a or replace exising header  to a SIP message.       */
@@ -82,21 +82,21 @@ osip_message_replace_header (osip_message_t * sip, const char *hname,
   osip_header_t *h, *oldh;
   int i, oldpos = -1;
 
-  if (hname == NULL)
-    return -1;
+  if (sip == NULL || hname == NULL)
+    return OSIP_BADPARAMETER;
 
   oldpos = osip_message_header_get_byname(sip, hname, 0, &oldh);
 
   i = osip_header_init (&h);
   if (i != 0)
-    return -1;
+    return i;
 
   h->hname = (char *) osip_malloc (strlen (hname) + 1);
 
   if (h->hname == NULL)
     {
       osip_header_free (h);
-      return -1;
+      return OSIP_NOMEM;
     }
   osip_clrncpy (h->hname, hname, strlen (hname));
 
@@ -106,7 +106,7 @@ osip_message_replace_header (osip_message_t * sip, const char *hname,
       if (h->hvalue == NULL)
 	{
 	  osip_header_free (h);
-	  return -1;
+	  return OSIP_NOMEM;
 	}
       osip_clrncpy (h->hvalue, hvalue, strlen (hvalue));
     } else
@@ -120,7 +120,7 @@ osip_message_replace_header (osip_message_t * sip, const char *hname,
 
   sip->message_property = 2;
   osip_list_add (&sip->headers, h, -1);
-  return 0;                     /* ok */
+  return OSIP_SUCCESS;                     /* ok */
 }
 
 
@@ -137,19 +137,19 @@ osip_message_set_topheader (osip_message_t * sip, const char *hname,
   osip_header_t *h;
   int i;
 
-  if (hname == NULL)
-    return -1;
+  if (sip == NULL || hname == NULL)
+    return OSIP_BADPARAMETER;
 
   i = osip_header_init (&h);
   if (i != 0)
-    return -1;
+    return i;
 
   h->hname = (char *) osip_malloc (strlen (hname) + 1);
 
   if (h->hname == NULL)
     {
       osip_header_free (h);
-      return -1;
+      return OSIP_NOMEM;
     }
   osip_clrncpy (h->hname, hname, strlen (hname));
 
@@ -159,14 +159,14 @@ osip_message_set_topheader (osip_message_t * sip, const char *hname,
       if (h->hvalue == NULL)
         {
           osip_header_free (h);
-          return -1;
+          return OSIP_NOMEM;
         }
       osip_clrncpy (h->hvalue, hvalue, strlen (hvalue));
   } else
     h->hvalue = NULL;
   sip->message_property = 2;
   osip_list_add (&sip->headers, h, 0);
-  return 0;                     /* ok */
+  return OSIP_SUCCESS;                     /* ok */
 }
 
 /* Get a header in a SIP message.                       */
@@ -179,7 +179,7 @@ osip_message_get_header (const osip_message_t * sip, int pos,
 {
   *dest = NULL;
   if (osip_list_size (&sip->headers) <= pos)
-    return -1;                  /* NULL */
+    return OSIP_UNDEFINED_ERROR;                  /* NULL */
   *dest = (osip_header_t *) osip_list_get (&sip->headers, pos);
   return pos;
 }
@@ -200,7 +200,7 @@ osip_message_header_get_byname (const osip_message_t * sip, const char *hname,
   *dest = NULL;
   i = pos;
   if (osip_list_size (&sip->headers) <= pos)
-    return -1;                  /* NULL */
+    return OSIP_UNDEFINED_ERROR;                  /* NULL */
   while (osip_list_size (&sip->headers) > i)
     {
       tmp = (osip_header_t *) osip_list_get (&sip->headers, i);
@@ -211,7 +211,7 @@ osip_message_header_get_byname (const osip_message_t * sip, const char *hname,
         }
       i++;
     }
-  return -1;                    /* not found */
+  return OSIP_UNDEFINED_ERROR;                    /* not found */
 }
 
 int
@@ -219,10 +219,10 @@ osip_header_init (osip_header_t ** header)
 {
   *header = (osip_header_t *) osip_malloc (sizeof (osip_header_t));
   if (*header == NULL)
-    return -1;
+    return OSIP_NOMEM;
   (*header)->hname = NULL;
   (*header)->hvalue = NULL;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 void
@@ -248,7 +248,7 @@ osip_header_to_str (const osip_header_t * header, char **dest)
 
   *dest = NULL;
   if ((header == NULL) || (header->hname == NULL))
-    return -1;
+    return OSIP_BADPARAMETER;
 
   len = 0;
   if (header->hvalue != NULL)
@@ -256,7 +256,7 @@ osip_header_to_str (const osip_header_t * header, char **dest)
 
   *dest = (char *) osip_malloc (strlen (header->hname) + len + 3);
   if (*dest == NULL)
-    return -1;
+    return OSIP_NOMEM;
 
   if (header->hvalue != NULL)
     sprintf (*dest, "%s: %s", header->hname, header->hvalue);
@@ -265,7 +265,7 @@ osip_header_to_str (const osip_header_t * header, char **dest)
 
   if (*dest[0] > 'a' && *dest[0] < 'z')
     *dest[0] = (*dest[0] - 32);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 char *
@@ -304,17 +304,30 @@ osip_header_clone (const osip_header_t * header, osip_header_t ** dest)
 
   *dest = NULL;
   if (header == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (header->hname == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
 
   i = osip_header_init (&he);
   if (i != 0)
-    return -1;
+    return i;
   he->hname = osip_strdup (header->hname);
+
+  if (he->hname==NULL)
+  {
+	  osip_header_free (he);
+	  return OSIP_NOMEM;
+  }
   if (header->hvalue != NULL)
-    he->hvalue = osip_strdup (header->hvalue);
+  {
+	  he->hvalue = osip_strdup (header->hvalue);
+	  if (he->hvalue==NULL)
+	  {
+		  osip_header_free (he);
+		  return OSIP_NOMEM;
+	  }
+  }
 
   *dest = he;
-  return 0;
+  return OSIP_SUCCESS;
 }
