@@ -60,11 +60,11 @@ __osip_message_startline_to_strreq (osip_message_t * sip, char **dest)
 
   *dest = NULL;
   if ((sip == NULL) || (sip->req_uri == NULL) || (sip->sip_method == NULL))
-    return -1;
+    return OSIP_BADPARAMETER;
 
   i = osip_uri_to_str (sip->req_uri, &rquri);
   if (i != 0)
-    return -1;
+    return i;
 
   if (sip->sip_version == NULL)
     sip_version = osip_protocol_version;
@@ -73,6 +73,11 @@ __osip_message_startline_to_strreq (osip_message_t * sip, char **dest)
 
   *dest = (char *) osip_malloc (strlen (sip->sip_method)
                                 + strlen (rquri) + strlen (sip_version) + 3);
+  if (*dest==NULL)
+  {
+	  osip_free (rquri);
+	  return OSIP_NOMEM;
+  }
   tmp = *dest;
 
   tmp = osip_str_append (tmp, sip->sip_method);
@@ -84,7 +89,7 @@ __osip_message_startline_to_strreq (osip_message_t * sip, char **dest)
   strcpy (tmp, sip_version);
 
   osip_free (rquri);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 static int
@@ -97,7 +102,7 @@ __osip_message_startline_to_strresp (osip_message_t * sip, char **dest)
   *dest = NULL;
   if ((sip == NULL) || (sip->reason_phrase == NULL)
       || (sip->status_code < 100) || (sip->status_code > 699))
-    return -1;
+    return OSIP_BADPARAMETER;
 
   if (sip->sip_version == NULL)
     sip_version = osip_protocol_version;
@@ -108,6 +113,8 @@ __osip_message_startline_to_strresp (osip_message_t * sip, char **dest)
 
   *dest = (char *) osip_malloc (strlen (sip_version)
                                 + 3 + strlen (sip->reason_phrase) + 4);
+  if (*dest==NULL)
+	  return OSIP_NOMEM;
   tmp = *dest;
 
   tmp = osip_str_append (tmp, sip_version);
@@ -119,7 +126,7 @@ __osip_message_startline_to_strresp (osip_message_t * sip, char **dest)
   tmp++;
   strcpy (tmp, sip->reason_phrase);
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 static int
@@ -134,7 +141,7 @@ __osip_message_startline_to_str (osip_message_t * sip, char **dest)
   OSIP_TRACE (osip_trace
               (__FILE__, __LINE__, TRACE_LEVEL1, NULL,
                "ERROR method has no value or status code is 0!\n"));
-  return -1;                    /* should never come here */
+  return OSIP_BADPARAMETER;                    /* should never come here */
 }
 
 char *
@@ -195,19 +202,19 @@ strcat_simple_header (char **_string, size_t * malloc_size,
             {
               *_string = NULL;
               *_message = NULL;
-              return -1;
+              return OSIP_NOMEM;
             }
           message = string + size;
         }
       message = osip_strn_append (message, header_name, size_of_header);
 
       i = xxx_to_str (ptr_header, &tmp);
-      if (i == -1)
+      if (i != 0)
         {
           *_string = string;
           *_message = message;
           *next = NULL;
-          return -1;
+          return i;
         }
       if (*malloc_size < message - string + strlen (tmp) + 100)
         {
@@ -219,7 +226,7 @@ strcat_simple_header (char **_string, size_t * malloc_size,
             {
               *_string = NULL;
               *_message = NULL;
-              return -1;
+              return OSIP_NOMEM;
             }
           message = string + size;
         }
@@ -231,7 +238,7 @@ strcat_simple_header (char **_string, size_t * malloc_size,
   *_string = string;
   *_message = message;
   *next = message;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 static int
@@ -266,18 +273,18 @@ strcat_headers_one_per_line (char **_string, size_t * malloc_size,
             {
               *_string = NULL;
               *_message = NULL;
-              return -1;
+              return OSIP_NOMEM;
             }
           message = string + size;
         }
       osip_strncpy (message, header, size_of_header);
       i = xxx_to_str (elt, &tmp);
-      if (i == -1)
+      if (i != 0)
         {
           *_string = string;
           *_message = message;
           *next = NULL;
-          return -1;
+          return i;
         }
       message = message + strlen (message);
 
@@ -291,7 +298,7 @@ strcat_headers_one_per_line (char **_string, size_t * malloc_size,
             {
               *_string = NULL;
               *_message = NULL;
-              return -1;
+              return OSIP_NOMEM;
             }
           message = string + size;
         }
@@ -303,7 +310,7 @@ strcat_headers_one_per_line (char **_string, size_t * malloc_size,
   *_string = string;
   *_message = message;
   *next = message;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 #if 0
@@ -336,7 +343,7 @@ strcat_headers_all_on_one_line (char **_string, size_t * malloc_size,
             {
               *_string = NULL;
               *_message = NULL;
-              return -1;
+              return OSIP_NOMEM;
             }
           message = string + size;
         }
@@ -348,12 +355,12 @@ strcat_headers_all_on_one_line (char **_string, size_t * malloc_size,
 
           elt = (void *) osip_list_get (headers, pos);
           i = xxx_to_str (elt, &tmp);
-          if (i == -1)
+          if (i != 0)
             {
               *_string = string;
               *_message = message;
               *next = NULL;
-              return -1;
+              return i;
             }
           if (*malloc_size < message - string + strlen (tmp) + 100)
             {
@@ -365,7 +372,7 @@ strcat_headers_all_on_one_line (char **_string, size_t * malloc_size,
                 {
                   *_string = NULL;
                   *_message = NULL;
-                  return -1;
+                  return OSIP_NOMEM;
                 }
               message = string + size;
             }
@@ -384,7 +391,7 @@ strcat_headers_all_on_one_line (char **_string, size_t * malloc_size,
   *_string = string;
   *_message = message;
   *next = message;
-  return 0;
+  return OSIP_SUCCESS;
 }
 #endif
 
@@ -397,7 +404,7 @@ int
 osip_message_get__property (const osip_message_t * sip)
 {
   if (sip == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   return sip->message_property;
 }
 
@@ -405,9 +412,9 @@ int
 osip_message_force_update (osip_message_t * sip)
 {
   if (sip == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   sip->message_property = 2;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 static int
@@ -421,11 +428,11 @@ _osip_message_realloc (char **message, char **dest, size_t needed,
       *malloc_size = size + needed + 100;
       *dest = osip_realloc (*dest, *malloc_size);
       if (*dest == NULL)
-        return -1;
+        return OSIP_NOMEM;
       *message = *dest + size;
     }
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 static int
@@ -449,8 +456,8 @@ _osip_message_to_str (osip_message_t * sip, char **dest,
   malloc_size = SIP_MESSAGE_MAX_LENGTH;
 
   *dest = NULL;
-  if ((sip == NULL))
-    return -1;
+  if (sip == NULL)
+    return OSIP_BADPARAMETER;
 
   {
     if (1 == osip_message_get__property (sip))
@@ -458,12 +465,12 @@ _osip_message_to_str (osip_message_t * sip, char **dest,
 
         *dest = osip_malloc (sip->message_length + 1);
         if (*dest == NULL)
-          return -1;
+          return OSIP_NOMEM;
         memcpy (*dest, sip->message, sip->message_length);
         (*dest)[sip->message_length] = '\0';
         if (message_length != NULL)
           *message_length = sip->message_length;
-        return 0;
+        return OSIP_SUCCESS;
     } else
       {
         /* message should be rebuilt: delete the old one if exists. */
@@ -474,18 +481,18 @@ _osip_message_to_str (osip_message_t * sip, char **dest,
 
   message = (char *) osip_malloc (SIP_MESSAGE_MAX_LENGTH);      /* ???? message could be > 4000  */
   if (message == NULL)
-    return -1;
+    return OSIP_NOMEM;
   *dest = message;
 
   /* add the first line of message */
   i = __osip_message_startline_to_str (sip, &tmp);
-  if (i == -1)
+  if (i != 0)
     {
       if (!sipfrag)
         {
           osip_free (*dest);
           *dest = NULL;
-          return -1;
+          return i;
         }
 
       /* A start-line isn't required for message/sipfrag parts. */
@@ -610,7 +617,7 @@ _osip_message_to_str (osip_message_t * sip, char **dest,
 	  {
 	    osip_free (*dest);
 	    *dest = NULL;
-	    return -1;
+	    return i;
 	  }
 	message = next;
 	
@@ -626,11 +633,11 @@ _osip_message_to_str (osip_message_t * sip, char **dest,
 
       header = (osip_header_t *) osip_list_get (&sip->headers, pos);
       i = osip_header_to_str (header, &tmp);
-      if (i == -1)
+      if (i != 0)
         {
           osip_free (*dest);
           *dest = NULL;
-          return -1;
+          return i;
         }
 
       header_len = strlen (tmp);
@@ -639,7 +646,7 @@ _osip_message_to_str (osip_message_t * sip, char **dest,
 	{
 	  osip_free (tmp);
           *dest = NULL;
-	  return -1;
+	  return OSIP_NOMEM;
 	}
 
       message = osip_str_append (message, tmp);
@@ -653,7 +660,7 @@ _osip_message_to_str (osip_message_t * sip, char **dest,
   /* add enough lenght for "Content-Length: " */
 
   if (_osip_message_realloc (&message, dest, 16, &malloc_size) < 0)
-    return -1;
+    return OSIP_NOMEM;
 
   if (sipfrag && osip_list_eol (&sip->bodies, 0))
     {
@@ -668,7 +675,7 @@ _osip_message_to_str (osip_message_t * sip, char **dest,
       if (message_length != NULL)
         *message_length = message - *dest;
 
-      return 0;                 /* it's all done */
+      return OSIP_SUCCESS;                 /* it's all done */
     }
 
   osip_strncpy (message, "Content-Length: ", 16);
@@ -679,10 +686,10 @@ _osip_message_to_str (osip_message_t * sip, char **dest,
      if (sip->contentlength!=NULL)
      {
      i = osip_content_length_to_str(sip->contentlength, &tmp);
-     if (i==-1) {
+     if (i!=0) {
      osip_free(*dest);
      *dest = NULL;
-     return -1;
+     return i;
      }
      osip_strncpy(message,tmp,strlen(tmp));
      osip_free(tmp);
@@ -724,7 +731,7 @@ _osip_message_to_str (osip_message_t * sip, char **dest,
       if (message_length != NULL)
         *message_length = total_length;
 
-      return 0;                 /* it's all done */
+      return OSIP_SUCCESS;                 /* it's all done */
     }
 
   if (sip->mime_version != NULL && sip->content_type
@@ -744,10 +751,16 @@ _osip_message_to_str (osip_message_t * sip, char **dest,
             {
               osip_free (*dest);
               *dest = NULL;
-              return -1;
+              return OSIP_SYNTAXERROR;
             }
 
           boundary = osip_malloc (len + 5);
+		  if (boundary==NULL)
+		  {
+              osip_free (*dest);
+              *dest = NULL;
+			  return OSIP_NOMEM;
+		  }
 
           osip_strncpy (boundary, CRLF, 2);
           osip_strncpy (boundary + 2, "--", 2);
@@ -782,7 +795,7 @@ _osip_message_to_str (osip_message_t * sip, char **dest,
           *dest = NULL;
           if (boundary)
             osip_free (boundary);
-          return -1;
+          return i;
         }
 
       if (malloc_size < message - *dest + 100 + body_length)
@@ -802,7 +815,7 @@ _osip_message_to_str (osip_message_t * sip, char **dest,
               osip_free (tmp);  /* fixed 09/Jun/2005 */
               if (boundary)
                 osip_free (boundary);
-              return -1;
+              return OSIP_NOMEM;
             }
           start_of_bodies = *dest + offset_of_body;
           if (content_length_to_modify != NULL)
@@ -834,7 +847,7 @@ _osip_message_to_str (osip_message_t * sip, char **dest,
     {
       osip_free (*dest);
       *dest = NULL;
-      return -1;
+      return OSIP_SYNTAXERROR;
     }
 
   /* we NOW have the length of bodies: */
@@ -859,7 +872,7 @@ _osip_message_to_str (osip_message_t * sip, char **dest,
       if (message_length != NULL)
         *message_length = total_length;
     }
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
