@@ -117,6 +117,79 @@ osip_free_func_t *osip_free_func = 0;
 #endif
 #endif
 
+const char *osip_error_table[] = {
+ "success",
+ "undefined error",
+ "bad parameter",
+ "wrong state",
+ "allocation failure",
+ "syntax error",
+ "not found",
+ "api not initialized",
+ "undefined",
+ "undefined",
+ "no network",        /* -10 */
+ "busy port",
+ "unknown host",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "disk full",        /* -30 */
+ "no rights",
+ "file not found",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",        /* -40 */
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "time out", /* -50 */
+ "too much call",
+ "wrong format",
+ "no common codec",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined",
+ "undefined", /* -60 */
+};
+
+const char *osip_strerror(int err)
+{
+	if (err>0)
+		return osip_error_table[0];
+	if (err>-60)
+		return osip_error_table[-err];
+	return osip_error_table[59];
+}
+
 #ifndef WIN32_USE_CRYPTO
 unsigned int
 osip_build_random_number ()
@@ -252,6 +325,8 @@ osip_strdup (const char *ch)
     return NULL;
   length = strlen (ch);
   copy = (char *) osip_malloc (length + 1);
+  if (copy==NULL)
+	  return NULL;
   osip_strncpy (copy, ch, length);
   return copy;
 }
@@ -264,10 +339,10 @@ osip_atoi (const char *number)
   int i;
 
   if (number == NULL)
-    return -1;
+    return OSIP_UNDEFINED_ERROR;
   i = strtol (number, (char **) NULL, 10);
   if (i == LONG_MIN || i == LONG_MAX)
-    return -1;
+    return OSIP_UNDEFINED_ERROR;
   return i;
 #endif
 
@@ -343,6 +418,8 @@ char *
 osip_strdup_without_quote (const char *ch)
 {
   char *copy = (char *) osip_malloc (strlen (ch) + 1);
+  if (copy==NULL)
+	  return NULL;
 
   /* remove leading and trailing " */
   if ((*ch == '\"'))
@@ -371,7 +448,7 @@ osip_tolower (char *word)
         word[i] = word[i] + 32;
     }
 #endif
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 #ifndef MINISIZE
@@ -399,7 +476,7 @@ osip_strncasecmp (const char *s1, const char *s2, size_t len)
 {
 #if defined(__VXWORKS_OS__) || defined( __PSOS__)
   if (len == 0)
-    return 0;
+    return OSIP_SUCCESS;
   while ((len > 0) && (tolower (*s1) == tolower (*s2)))
     {
       len--;
@@ -428,9 +505,9 @@ osip_clrspace (char *word)
   size_t len;
 
   if (word == NULL)
-    return -1;
+    return OSIP_UNDEFINED_ERROR;
   if (*word == '\0')
-    return 0;
+    return OSIP_SUCCESS;
   len = strlen (word);
 
   pbeg = word;
@@ -444,7 +521,7 @@ osip_clrspace (char *word)
       if (pend < pbeg)
         {
           *word = '\0';
-          return 0;
+          return OSIP_SUCCESS;
         }
     }
 
@@ -455,7 +532,7 @@ osip_clrspace (char *word)
   if (pbeg != word)
     memmove (word, pbeg, pend - pbeg + 2);
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 /* __osip_set_next_token:
@@ -484,18 +561,20 @@ __osip_set_next_token (char **dest, char *buf, int end_separator, char **next)
   if ((*sep == '\r') || (*sep == '\n'))
     {                           /* we should continue normally only if this is the separator asked! */
       if (*sep != end_separator)
-        return -1;
+        return OSIP_UNDEFINED_ERROR;
     }
   if (*sep == '\0')
-    return -1;                  /* value must not end with this separator! */
+    return OSIP_UNDEFINED_ERROR;                  /* value must not end with this separator! */
   if (sep == buf)
-    return -1;                  /* empty value (or several space!) */
+    return OSIP_UNDEFINED_ERROR;                  /* empty value (or several space!) */
 
   *dest = osip_malloc (sep - (buf) + 1);
+  if (*dest==NULL)
+	  return OSIP_NOMEM;
   osip_strncpy (*dest, buf, sep - buf);
 
   *next = sep + 1;              /* return the position right after the separator */
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 #if 0
@@ -516,14 +595,16 @@ __osip_set_next_token_better (char **dest, char *buf, int end_separator,
   if ((*sep == '\r') && (*sep == '\n'))
     {                           /* we should continue normally only if this is the separator asked! */
       if (*sep != end_separator)
-        return -1;
+        return OSIP_UNDEFINED_ERROR;
     }
   if (*sep == '\0')
-    return -1;                  /* value must not end with this separator! */
+    return OSIP_UNDEFINED_ERROR;                  /* value must not end with this separator! */
   if (sep == buf)
-    return -1;                  /* empty value (or several space!) */
+    return OSIP_UNDEFINED_ERROR;                  /* empty value (or several space!) */
 
   *dest = osip_malloc (sep - (buf) + 1);
+  if (*dest==NULL)
+	  return OSIP_NOMEM;
   osip_strncpy (*dest, buf, sep - buf);
 
   *next = sep + 1;              /* return the position right after the separator */
@@ -603,6 +684,8 @@ osip_enquote (const char *s)
   char *t;
 
   t = rtn = osip_malloc (strlen (s) * 2 + 3);
+  if (rtn==NULL)
+	  return NULL;
   *t++ = '"';
   for (; *s != '\0'; s++)
     {
@@ -801,7 +884,7 @@ osip_trace (char *fi, int li, osip_trace_level_t level, FILE * f, char *chfr, ..
 #endif
 
   if (tracing_table[level] == LOG_FALSE)
-    return 0;
+    return OSIP_SUCCESS;
 
   if (f == NULL && trace_func == NULL)
     f = logfile;
@@ -913,7 +996,7 @@ osip_trace (char *fi, int li, osip_trace_level_t level, FILE * f, char *chfr, ..
 
   va_end (ap);
 #endif
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 
@@ -1007,7 +1090,7 @@ osip_vsnprintf (char *buf, int max, const char *fmt, va_list ap)
 
   if (fioFormatV (fmt, ap, _cb_snprintf, (int) &ctx) != OK)
     {
-      return -1;
+      return OSIP_UNDEFINED_ERROR;
     }
 
   return ctx.len;
@@ -1044,7 +1127,7 @@ osip_snprintf (char *buf, int max, const char *fmt, ...)
   retval = strlen (buffer);
   memmove (buf, buffer, max);
   if (retval > max)
-    return -1;
+    return OSIP_UNDEFINED_ERROR;
   return retval;
 }
 
