@@ -43,20 +43,20 @@ osip_message_set_record_route (osip_message_t * sip, const char *hvalue)
   int i;
 
   if (hvalue == NULL || hvalue[0] == '\0')
-    return 0;
+    return OSIP_SUCCESS;
 
   i = osip_record_route_init (&record_route);
   if (i != 0)
-    return -1;
+    return i;
   i = osip_record_route_parse (record_route, hvalue);
   if (i != 0)
     {
       osip_record_route_free (record_route);
-      return -1;
+      return i;
     }
   sip->message_property = 2;
   osip_list_add (&sip->record_routes, record_route, -1);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 #ifndef MINISIZE
@@ -71,7 +71,7 @@ osip_message_get_record_route (const osip_message_t * sip, int pos,
 
   *dest = NULL;
   if (osip_list_size (&sip->record_routes) <= pos)
-    return -1;                  /* does not exist */
+    return OSIP_UNDEFINED_ERROR;     /* does not exist */
   record_route = (osip_record_route_t *) osip_list_get (&sip->record_routes, pos);
   *dest = record_route;
   return pos;
@@ -98,11 +98,11 @@ osip_record_route_to_str (const osip_record_route_t * record_route, char **dest)
 
   *dest = NULL;
   if ((record_route == NULL) || (record_route->url == NULL))
-    return -1;
+    return OSIP_BADPARAMETER;
 
   i = osip_uri_to_str (record_route->url, &url);
   if (i != 0)
-    return -1;
+    return i;
 
   if (record_route->displayname == NULL)
     len = strlen (url) + 5;
@@ -113,7 +113,7 @@ osip_record_route_to_str (const osip_record_route_t * record_route, char **dest)
   if (buf == NULL)
     {
       osip_free (url);
-      return -1;
+      return OSIP_NOMEM;
     }
 
   /* route and record-route always use brackets */
@@ -150,7 +150,7 @@ osip_record_route_to_str (const osip_record_route_t * record_route, char **dest)
       }
   }
   *dest = buf;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 /* deallocates a osip_record_route_t structure.  */
