@@ -31,7 +31,7 @@ osip_uri_init (osip_uri_t ** url)
 {
   *url = (osip_uri_t *) osip_malloc (sizeof (osip_uri_t));
   if (*url == NULL)
-    return -1;
+    return OSIP_NOMEM;
   (*url)->scheme = NULL;
   (*url)->username = NULL;
   (*url)->password = NULL;
@@ -43,7 +43,7 @@ osip_uri_init (osip_uri_t ** url)
   osip_list_init (&(*url)->url_headers);
 
   (*url)->string = NULL;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 /* examples:
@@ -107,17 +107,17 @@ osip_uri_parse (osip_uri_t * url, const char *buf)
 
   /* basic tests */
   if (buf == NULL || buf[0] == '\0')
-    return -1;
+    return OSIP_BADPARAMETER;
 
   tmp = strchr (buf, ':');
   if (tmp == NULL)
-    return -1;
+    return OSIP_SYNTAXERROR;
 
   if (tmp - buf < 2)
-    return -1;
+    return OSIP_SYNTAXERROR;
   url->scheme = (char *) osip_malloc (tmp - buf + 1);
   if (url->scheme == NULL)
-    return -1;
+    return OSIP_NOMEM;
   osip_strncpy (url->scheme, buf, tmp - buf);
 
   if (strlen (url->scheme) < 3 ||
@@ -127,12 +127,12 @@ osip_uri_parse (osip_uri_t * url, const char *buf)
       size_t i = strlen (tmp + 1);
 
       if (i < 2)
-        return -1;
+        return OSIP_SYNTAXERROR;
       url->string = (char *) osip_malloc (i + 1);
       if (url->string == NULL)
-        return -1;
+        return OSIP_NOMEM;
       osip_strncpy (url->string, tmp + 1, i);
-      return 0;
+      return OSIP_SUCCESS;
     }
 
   /*  law number 1:
@@ -147,7 +147,7 @@ osip_uri_parse (osip_uri_t * url, const char *buf)
   username = strchr (buf, ':');
   /* if ':' does not exist, the url is not valid */
   if (username == NULL)
-    return -1;
+    return OSIP_SYNTAXERROR;
 
   host = strchr (buf, '@');
 
@@ -165,19 +165,19 @@ osip_uri_parse (osip_uri_t * url, const char *buf)
         /* password exists */
         {
           if (host - password < 2)
-            return -1;
+            return OSIP_SYNTAXERROR;
           url->password = (char *) osip_malloc (host - password);
           if (url->password == NULL)
-            return -1;
+            return OSIP_NOMEM;
           osip_strncpy (url->password, password + 1, host - password - 1);
           __osip_uri_unescape (url->password);
         }
       if (password - username < 2)
-        return -1;
+        return OSIP_SYNTAXERROR;
       {
         url->username = (char *) osip_malloc (password - username);
         if (url->username == NULL)
-          return -1;
+          return OSIP_NOMEM;
         osip_strncpy (url->username, username + 1, password - username - 1);
         __osip_uri_unescape (url->username);
       }
@@ -204,10 +204,10 @@ osip_uri_parse (osip_uri_t * url, const char *buf)
       char *tmpbuf;
 
       if (headers - params + 1 < 2)
-        return -1;
+        return OSIP_SYNTAXERROR;
       tmpbuf = osip_malloc (headers - params + 1);
       if (tmpbuf == NULL)
-        return -1;
+        return OSIP_NOMEM;
       tmpbuf = osip_strncpy (tmpbuf, params, headers - params);
       osip_uri_parse_params (url, tmpbuf);
       osip_free (tmpbuf);
@@ -223,10 +223,10 @@ osip_uri_parse (osip_uri_t * url, const char *buf)
       else
         {
           if ((params - port < 2) || (params - port > 8))
-            return -1;          /* error cases */
+            return OSIP_SYNTAXERROR;          /* error cases */
           url->port = (char *) osip_malloc (params - port);
           if (url->port == NULL)
-            return -1;
+            return OSIP_NOMEM;
           osip_clrncpy (url->port, port + 1, params - port - 1);
         }
   } else
@@ -241,17 +241,17 @@ osip_uri_parse (osip_uri_t * url, const char *buf)
       while (host < port && *host != '[')
         host++;
       if (host >= port)
-        return -1;
+        return OSIP_SYNTAXERROR;
     }
 
   if (port - host < 2)
-    return -1;
+    return OSIP_SYNTAXERROR;
   url->host = (char *) osip_malloc (port - host);
   if (url->host == NULL)
-    return -1;
+    return OSIP_NOMEM;
   osip_clrncpy (url->host, host + 1, port - host - 1);
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 void
@@ -348,7 +348,7 @@ osip_uri_parse_headers (osip_uri_t * url, const char *headers)
   and = strchr (headers + 1, '&');
 
   if (equal == NULL)            /* each header MUST have a value */
-    return -1;
+    return OSIP_SYNTAXERROR;
 
   do
     {
@@ -357,7 +357,7 @@ osip_uri_parse_headers (osip_uri_t * url, const char *headers)
 
       hname = (char *) osip_malloc (equal - headers);
       if (hname == NULL)
-        return -1;
+        return OSIP_NOMEM;
       osip_strncpy (hname, headers + 1, equal - headers - 1);
       __osip_uri_unescape (hname);
 
@@ -366,13 +366,13 @@ osip_uri_parse_headers (osip_uri_t * url, const char *headers)
           if (and - equal < 2)
             {
               osip_free (hname);
-              return -1;
+              return OSIP_SYNTAXERROR;
             }
           hvalue = (char *) osip_malloc (and - equal);
           if (hvalue == NULL)
             {
               osip_free (hname);
-              return -1;
+              return OSIP_NOMEM;
             }
           osip_strncpy (hvalue, equal + 1, and - equal - 1);
           __osip_uri_unescape (hvalue);
@@ -381,13 +381,13 @@ osip_uri_parse_headers (osip_uri_t * url, const char *headers)
           if (headers + strlen (headers) - equal + 1 < 2)
             {
               osip_free (hname);
-              return -1;
+              return OSIP_SYNTAXERROR;
             }
           hvalue = (char *) osip_malloc (headers + strlen (headers) - equal + 1);
           if (hvalue == NULL)
             {
               osip_free (hname);
-              return -1;
+              return OSIP_NOMEM;
             }
           osip_strncpy (hvalue, equal + 1, headers + strlen (headers) - equal);
           __osip_uri_unescape (hvalue);
@@ -403,11 +403,11 @@ osip_uri_parse_headers (osip_uri_t * url, const char *headers)
           equal = strchr (headers, '=');
           and = strchr (headers + 1, '&');
           if (equal == NULL)    /* each header MUST have a value */
-            return -1;
+            return OSIP_SYNTAXERROR;
         }
     }
   while (equal != NULL);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -434,10 +434,10 @@ osip_uri_parse_params (osip_uri_t * url, const char *params)
       } else
         {
           if (comma - equal < 2)
-            return -1;
+            return OSIP_SYNTAXERROR;
           pvalue = (char *) osip_malloc (comma - equal);
           if (pvalue == NULL)
-            return -1;
+            return OSIP_NOMEM;
           osip_strncpy (pvalue, equal + 1, comma - equal - 1);
           __osip_uri_unescape (pvalue);
         }
@@ -445,13 +445,13 @@ osip_uri_parse_params (osip_uri_t * url, const char *params)
       if (equal - params < 2)
         {
           osip_free (pvalue);
-          return -1;
+          return OSIP_SYNTAXERROR;
         }
       pname = (char *) osip_malloc (equal - params);
       if (pname == NULL)
         {
           osip_free (pvalue);
-          return -1;
+          return OSIP_NOMEM;
         }
       osip_strncpy (pname, params + 1, equal - params - 1);
       __osip_uri_unescape (pname);
@@ -473,29 +473,29 @@ osip_uri_parse_params (osip_uri_t * url, const char *params)
   } else
     {
       if (comma - equal < 2)
-        return -1;
+        return OSIP_SYNTAXERROR;
       pvalue = (char *) osip_malloc (comma - equal);
       if (pvalue == NULL)
-        return -1;
+        return OSIP_NOMEM;
       osip_strncpy (pvalue, equal + 1, comma - equal - 1);
     }
 
   if (equal - params < 2)
     {
       osip_free (pvalue);
-      return -1;
+      return OSIP_SYNTAXERROR;
     }
   pname = (char *) osip_malloc (equal - params);
   if (pname == NULL)
     {
       osip_free (pvalue);
-      return -1;
+      return OSIP_NOMEM;
     }
   osip_strncpy (pname, params + 1, equal - params - 1);
 
   osip_uri_uparam_add (url, pname, pvalue);
 
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -509,11 +509,11 @@ osip_uri_to_str (const osip_uri_t * url, char **dest)
 
   *dest = NULL;
   if (url == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (url->host == NULL && url->string == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (url->scheme == NULL && url->string != NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (url->string == NULL && url->scheme == NULL)
     scheme = "sip";             /* default is sipurl */
   else
@@ -523,13 +523,13 @@ osip_uri_to_str (const osip_uri_t * url, char **dest)
     {
       buf = (char *) osip_malloc (strlen (scheme) + strlen (url->string) + 3);
       if (buf == NULL)
-        return -1;
+        return OSIP_NOMEM;
       *dest = buf;
       sprintf (buf, "%s:", scheme);
       buf = buf + strlen (scheme) + 1;
       sprintf (buf, "%s", url->string);
       buf = buf + strlen (url->string);
-      return 0;
+      return OSIP_SUCCESS;
     }
 
   len = strlen (scheme) + 1 + strlen (url->host) + 5;
@@ -542,7 +542,7 @@ osip_uri_to_str (const osip_uri_t * url, char **dest)
 
   buf = (char *) osip_malloc (len);
   if (buf == NULL)
-    return -1;
+    return OSIP_NOMEM;
   tmp = buf;
 
   sprintf (tmp, "%s:", scheme);
@@ -634,7 +634,7 @@ osip_uri_to_str (const osip_uri_t * url, char **dest)
         if (tmp1 == NULL)
           {
             osip_free (buf);
-            return -1;
+            return OSIP_SYNTAXERROR;
           }
 
         tmp2 = __osip_uri_escape_header_param (u_header->gvalue);
@@ -643,7 +643,7 @@ osip_uri_to_str (const osip_uri_t * url, char **dest)
           {
             osip_free (tmp1);
             osip_free (buf);
-            return -1;
+            return OSIP_SYNTAXERROR;
           }
         plen = strlen (tmp1) + strlen (tmp2) + 4;
 
@@ -662,7 +662,7 @@ osip_uri_to_str (const osip_uri_t * url, char **dest)
   }
 
   *dest = buf;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 
@@ -705,13 +705,13 @@ osip_uri_clone (const osip_uri_t * url, osip_uri_t ** dest)
 
   *dest = NULL;
   if (url == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (url->host == NULL && url->string == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
 
   i = osip_uri_init (&ur);
-  if (i == -1)                  /* allocation failed */
-    return -1;
+  if (i != 0)                  /* allocation failed */
+    return i;
   if (url->scheme != NULL)
     ur->scheme = osip_strdup (url->scheme);
   if (url->username != NULL)
@@ -725,29 +725,31 @@ osip_uri_clone (const osip_uri_t * url, osip_uri_t ** dest)
   if (url->string != NULL)
     ur->string = osip_strdup (url->string);
 
-  i = osip_list_clone(&url->url_params, &ur->url_params, (int *(*)(void *, void *)) &osip_uri_param_clone);
+  i = osip_list_clone(&url->url_params, &ur->url_params, &osip_uri_param_clone);
   if (i != 0)
     {
       osip_uri_free(ur);
-      return -1;
+      return i;
     }
-  i = osip_list_clone(&url->url_headers, &ur->url_headers, (int *(*)(void *, void *)) &osip_uri_param_clone);
+  i = osip_list_clone(&url->url_headers, &ur->url_headers, &osip_uri_param_clone);
   if (i != 0)
     {
       osip_uri_free(ur);
-      return -1;
+      return i;
     }
   *dest = ur;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
 osip_uri_param_init (osip_uri_param_t ** url_param)
 {
   *url_param = (osip_uri_param_t *) osip_malloc (sizeof (osip_uri_param_t));
+  if (*url_param==NULL)
+	  return OSIP_NOMEM;
   (*url_param)->gname = NULL;
   (*url_param)->gvalue = NULL;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 void
@@ -767,7 +769,7 @@ osip_uri_param_set (osip_uri_param_t * url_param, char *pname, char *pvalue)
   url_param->gvalue = pvalue;
   if (url_param->gvalue != NULL)
     osip_clrspace (url_param->gvalue);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -778,15 +780,15 @@ osip_uri_param_add (osip_list_t * url_params, char *pname, char *pvalue)
 
   i = osip_uri_param_init (&url_param);
   if (i != 0)
-    return -1;
+    return i;
   i = osip_uri_param_set (url_param, pname, pvalue);
   if (i != 0)
     {
       osip_uri_param_free (url_param);
-      return -1;
+      return i;
     }
   osip_list_add (url_params, url_param, -1);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 void
@@ -812,10 +814,10 @@ osip_uri_param_get_byname (osip_list_t * params, char *pname,
 
   *url_param = NULL;
   if (pname == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   pname_len = strlen (pname);
   if (pname_len <= 0)
-    return -1;
+    return OSIP_BADPARAMETER;
   while (!osip_list_eol (params, pos))
     {
       size_t len;
@@ -826,11 +828,11 @@ osip_uri_param_get_byname (osip_list_t * params, char *pname,
           && osip_strncasecmp (u_param->gname, pname, strlen (pname)) == 0)
         {
           *url_param = u_param;
-          return 0;
+          return OSIP_SUCCESS;
         }
       pos++;
     }
-  return -1;
+  return OSIP_UNDEFINED_ERROR;
 }
 
 int
@@ -841,20 +843,20 @@ osip_uri_param_clone (const osip_uri_param_t * uparam, osip_uri_param_t ** dest)
 
   *dest = NULL;
   if (uparam == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (uparam->gname == NULL)
-    return -1;                  /* name is mandatory */
+    return OSIP_BADPARAMETER;                  /* name is mandatory */
 
   i = osip_uri_param_init (&up);
   if (i != 0)                   /* allocation failed */
-    return -1;
+    return i;
   up->gname = osip_strdup (uparam->gname);
   if (uparam->gvalue != NULL)
     up->gvalue = osip_strdup (uparam->gvalue);
   else
     up->gvalue = NULL;
   *dest = up;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 
@@ -877,13 +879,16 @@ __osip_uri_escape_nonascii_and_nondef (const char *string, const char *def)
 {
   size_t alloc = strlen (string) + 1;
   size_t length;
-  char *ns = osip_malloc (alloc);
+  char *ns = (char*) osip_malloc (alloc);
   unsigned char in;
   size_t newlen = alloc;
   int index = 0;
   const char *tmp;
   int i;
 
+  if (ns==NULL)
+	  return NULL;
+
   length = alloc - 1;
   while (length--)
     {
