@@ -29,9 +29,9 @@ int
 sdp_message_v_version_set (sdp_message_t * sdp, char *v_version)
 {
   if (sdp == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   sdp->v_version = v_version;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 char *
@@ -48,14 +48,14 @@ sdp_message_o_origin_set (sdp_message_t * sdp, char *username, char *sess_id,
                           char *addr)
 {
   if (sdp == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   sdp->o_username = username;
   sdp->o_sess_id = sess_id;
   sdp->o_sess_version = sess_version;
   sdp->o_nettype = nettype;
   sdp->o_addrtype = addrtype;
   sdp->o_addr = addr;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 char *
@@ -112,7 +112,7 @@ sdp_message_s_name_set (sdp_message_t * sdp, char *name)
   if (sdp == NULL)
     return -1;
   sdp->s_name = name;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 char *
@@ -129,17 +129,17 @@ sdp_message_i_info_set (sdp_message_t * sdp, int pos_media, char *info)
   sdp_media_t *med;
 
   if (sdp == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (pos_media == -1)
     {
       sdp->i_info = info;
-      return 0;
+      return OSIP_SUCCESS;
     }
   med = osip_list_get (&sdp->m_medias, pos_media);
   if (med == NULL)
-    return -1;
+    return OSIP_UNDEFINED_ERROR;
   med->i_info = info;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 char *
@@ -163,9 +163,9 @@ int
 sdp_message_u_uri_set (sdp_message_t * sdp, char *uri)
 {
   if (sdp == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   sdp->u_uri = uri;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 char *
@@ -180,9 +180,9 @@ int
 sdp_message_e_email_add (sdp_message_t * sdp, char *email)
 {
   if (sdp == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   osip_list_add (&sdp->e_emails, email, -1);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 char *
@@ -199,9 +199,9 @@ int
 sdp_message_p_phone_add (sdp_message_t * sdp, char *phone)
 {
   if (sdp == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   osip_list_add (&sdp->p_phones, phone, -1);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 char *
@@ -225,12 +225,12 @@ sdp_message_c_connection_add (sdp_message_t * sdp, int pos_media,
   sdp_connection_t *conn;
 
   if (sdp == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if ((pos_media != -1) && (osip_list_size (&sdp->m_medias) < pos_media + 1))
     return -1;
   i = sdp_connection_init (&conn);
   if (i != 0)
-    return -1;
+    return i;
   conn->c_nettype = nettype;
   conn->c_addrtype = addrtype;
   conn->c_addr = addr;
@@ -239,11 +239,11 @@ sdp_message_c_connection_add (sdp_message_t * sdp, int pos_media,
   if (pos_media == -1)
     {
       sdp->c_connection = conn;
-      return 0;
+      return OSIP_SUCCESS;
     }
   med = (sdp_media_t *) osip_list_get (&sdp->m_medias, pos_media);
   osip_list_add (&med->c_connections, conn, -1);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 /* this method should be internal only... */
@@ -321,22 +321,22 @@ sdp_message_b_bandwidth_add (sdp_message_t * sdp, int pos_media, char *bwtype,
   sdp_bandwidth_t *band;
 
   if (sdp == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if ((pos_media != -1) && (osip_list_size (&sdp->m_medias) < pos_media + 1))
-    return -1;
+    return OSIP_UNDEFINED_ERROR;
   i = sdp_bandwidth_init (&band);
   if (i != 0)
-    return -1;
+    return i;
   band->b_bwtype = bwtype;
   band->b_bandwidth = bandwidth;
   if (pos_media == -1)
     {
       osip_list_add (&sdp->b_bandwidths, band, -1);
-      return 0;
+      return OSIP_SUCCESS;
     }
   med = (sdp_media_t *) osip_list_get (&sdp->m_medias, pos_media);
   osip_list_add (&med->b_bandwidths, band, -1);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 sdp_bandwidth_t *
@@ -381,14 +381,14 @@ sdp_message_t_time_descr_add (sdp_message_t * sdp, char *start, char *stop)
   sdp_time_descr_t *td;
 
   if (sdp == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   i = sdp_time_descr_init (&td);
   if (i != 0)
-    return -1;
+    return i;
   td->t_start_time = start;
   td->t_stop_time = stop;
   osip_list_add (&sdp->t_descrs, td, -1);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 char *
@@ -423,12 +423,12 @@ sdp_message_r_repeat_add (sdp_message_t * sdp, int pos_time_descr, char *field)
   sdp_time_descr_t *td;
 
   if (sdp == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   td = (sdp_time_descr_t *) osip_list_get (&sdp->t_descrs, pos_time_descr);
   if (td == NULL)
-    return -1;
+    return OSIP_UNDEFINED_ERROR;
   osip_list_add (&td->r_repeats, field, -1);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 char *
@@ -448,9 +448,9 @@ int
 sdp_message_z_adjustments_set (sdp_message_t * sdp, char *field)
 {
   if (sdp == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   sdp->z_adjustments = field;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 char *
@@ -469,20 +469,20 @@ sdp_message_k_key_set (sdp_message_t * sdp, int pos_media, char *keytype,
   sdp_media_t *med;
 
   if (sdp == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if ((pos_media != -1) && (osip_list_size (&sdp->m_medias) < pos_media + 1))
-    return -1;
+    return OSIP_UNDEFINED_ERROR;
   sdp_key_init (&key);
   key->k_keytype = keytype;
   key->k_keydata = keydata;
   if (pos_media == -1)
     {
       sdp->k_key = key;
-      return 0;
+      return OSIP_SUCCESS;
     }
   med = (sdp_media_t *) osip_list_get (&sdp->m_medias, pos_media);
   med->k_key = key;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 char *
@@ -536,22 +536,22 @@ sdp_message_a_attribute_add (sdp_message_t * sdp, int pos_media,
   sdp_attribute_t *attr;
 
   if (sdp == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if ((pos_media != -1) && (osip_list_size (&sdp->m_medias) < pos_media + 1))
-    return -1;
+    return OSIP_UNDEFINED_ERROR;
   i = sdp_attribute_init (&attr);
   if (i != 0)
-    return -1;
+    return i;
   attr->a_att_field = att_field;
   attr->a_att_value = att_value;
   if (pos_media == -1)
     {
       osip_list_add (&sdp->a_attributes, attr, -1);
-      return 0;
+      return OSIP_SUCCESS;
     }
   med = (sdp_media_t *) osip_list_get (&sdp->m_medias, pos_media);
   osip_list_add (&med->a_attributes, attr, -1);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -562,9 +562,9 @@ sdp_message_a_attribute_del (sdp_message_t * sdp, int pos_media, char *att_field
   sdp_attribute_t *attr;
 
   if (sdp == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if ((pos_media != -1) && (osip_list_size (&sdp->m_medias) < pos_media + 1))
-    return -1;
+    return OSIP_UNDEFINED_ERROR;
   if (pos_media == -1)
     {
       for (i = 0; i < osip_list_size (&sdp->a_attributes);)
@@ -577,11 +577,11 @@ sdp_message_a_attribute_del (sdp_message_t * sdp, int pos_media, char *att_field
           } else
             i++;
         }
-      return 0;
+      return OSIP_SUCCESS;
     }
   med = (sdp_media_t *) osip_list_get (&sdp->m_medias, pos_media);
   if (med == NULL)
-    return -1;
+    return OSIP_UNDEFINED_ERROR;
   for (i = 0; i < osip_list_size (&med->a_attributes);)
     {
       attr = osip_list_get (&med->a_attributes, i);
@@ -592,7 +592,7 @@ sdp_message_a_attribute_del (sdp_message_t * sdp, int pos_media, char *att_field
       } else
         i++;
     }
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 int
@@ -604,9 +604,9 @@ sdp_message_a_attribute_del_at_index (sdp_message_t * sdp, int pos_media,
   sdp_attribute_t *attr;
 
   if (sdp == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if ((pos_media != -1) && (osip_list_size (&sdp->m_medias) < pos_media + 1))
-    return -1;
+    return OSIP_UNDEFINED_ERROR;
   if (pos_media == -1)
     {
       if (pos_attr == -1)
@@ -626,11 +626,11 @@ sdp_message_a_attribute_del_at_index (sdp_message_t * sdp, int pos_media,
           osip_list_remove (&sdp->a_attributes, pos_attr);
           sdp_attribute_free (attr);
         }
-      return 0;
+      return OSIP_SUCCESS;
     }
   med = (sdp_media_t *) osip_list_get (&sdp->m_medias, pos_media);
   if (med == NULL)
-    return -1;
+    return OSIP_UNDEFINED_ERROR;
   for (i = 0; i < osip_list_size (&med->a_attributes);)
     {
       if (pos_attr == -1)
@@ -648,7 +648,7 @@ sdp_message_a_attribute_del_at_index (sdp_message_t * sdp, int pos_media,
           sdp_attribute_free (attr);
         }
     }
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 
@@ -691,12 +691,12 @@ int
 sdp_message_endof_media (sdp_message_t * sdp, int i)
 {
   if (sdp == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (i == -1)
-    return 0;
+    return OSIP_SUCCESS;
   if (!osip_list_eol (&sdp->m_medias, i))
-    return 0;                   /* not end of list */
-  return -1;                    /* end of list */
+    return OSIP_SUCCESS;                   /* not end of list */
+  return OSIP_UNDEFINED_ERROR;                    /* end of list */
 }
 
 int
@@ -708,13 +708,13 @@ sdp_message_m_media_add (sdp_message_t * sdp, char *media,
 
   i = sdp_media_init (&med);
   if (i != 0)
-    return -1;
+    return i;
   med->m_media = media;
   med->m_port = port;
   med->m_number_of_port = number_of_port;
   med->m_proto = proto;
   osip_list_add (&sdp->m_medias, med, -1);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 char *
@@ -753,11 +753,11 @@ sdp_message_m_port_set (sdp_message_t * sdp, int pos_media, char *port)
   sdp_media_t *med = osip_list_get (&sdp->m_medias, pos_media);
 
   if (med == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if (med->m_port)
     osip_free (med->m_port);
   med->m_port = port;
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 char *
@@ -776,9 +776,9 @@ sdp_message_m_payload_add (sdp_message_t * sdp, int pos_media, char *payload)
   sdp_media_t *med = osip_list_get (&sdp->m_medias, pos_media);
 
   if (med == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   osip_list_add (&med->m_payloads, payload, -1);
-  return 0;
+  return OSIP_SUCCESS;
 }
 
 char *
@@ -798,10 +798,10 @@ sdp_message_m_payload_del (sdp_message_t * sdp, int pos_media, int pos)
   char *payload;
 
   if (med == NULL)
-    return -1;
+    return OSIP_BADPARAMETER;
   if ((payload = osip_list_get (&med->m_payloads, pos)) == NULL)
-    return -1;
+    return OSIP_UNDEFINED_ERROR;
   osip_list_remove (&med->m_payloads, pos);
   osip_free (payload);
-  return 0;
+  return OSIP_SUCCESS;
 }
